package Test::ConfigFromFile;
use Mouse;

extends 'MouseX::App::Cmd';

1;
